@@ -4,17 +4,14 @@ from cannerflow.request import CannerRequest
 
 
 class SavedQuery(object):
-    def __init__(
-        self,
-        request: CannerRequest,
-        workspace_id: str
-    ):
+    def __init__(self, request: CannerRequest, workspace_id: str):
         self.workspace_id = workspace_id
         self.request = request
+
     def getPayload(self):
         return {
-            'operationName': 'sqls',
-            'query': """
+            "operationName": "sqls",
+            "query": """
                 query sqls($where: SqlWhereInput!) {
                     sqls(where: $where) {
                         id
@@ -25,19 +22,17 @@ class SavedQuery(object):
                     }
                 }
             """,
-            'variables': {
-                'where': {
-                    'workspaceId': self.workspace_id
-                }
-            }
+            "variables": {"where": {"workspaceId": self.workspace_id}},
         }
+
     def fetch(self):
-        return self.request.graphql_exec(self.getPayload()).get('sqls')
+        return self.request.graphql_exec(self.getPayload()).get("sqls")
+
     def list_title(self):
         data = self.fetch()
-        return list(map(lambda x: x['title'], data))
+        return list(map(lambda x: x["title"], data))
+
     def get(self, title):
         queries = self.fetch()
-        query = next(q for q in queries if q.get('title') == title)
-        return  query
-
+        query = next(q for q in queries if q.get("title") == title)
+        return query
